pub struct Sprite {Show 80 fields
pub image_id: Option<ImageId>,
pub mask_image_id: Option<ImageId>,
pub mask_offset_x: i32,
pub mask_offset_y: i32,
pub tonecurve_image_id: Option<ImageId>,
pub tonecurve_row: f32,
pub tonecurve_sat: f32,
pub fit: SpriteFit,
pub size_mode: SpriteSizeMode,
pub visible: bool,
pub alpha: u8,
pub x: i32,
pub y: i32,
pub z: f32,
pub scale_x: f32,
pub scale_y: f32,
pub scale_z: f32,
pub rotate: f32,
pub rotate_x: f32,
pub rotate_y: f32,
pub pivot_x: f32,
pub pivot_y: f32,
pub pivot_z: f32,
pub object_anchor: bool,
pub texture_center_x: f32,
pub texture_center_y: f32,
pub camera_enabled: bool,
pub camera_eye: [f32; 3],
pub camera_target: [f32; 3],
pub camera_up: [f32; 3],
pub camera_view_angle_deg: f32,
pub culling: bool,
pub alpha_test: bool,
pub alpha_blend: bool,
pub fog_use: bool,
pub light_no: i32,
pub light_enabled: bool,
pub light_diffuse: [f32; 4],
pub light_ambient: [f32; 4],
pub light_specular: [f32; 4],
pub light_factor: f32,
pub light_kind: i32,
pub light_pos: [f32; 4],
pub light_dir: [f32; 4],
pub light_atten: [f32; 4],
pub light_cone: [f32; 4],
pub mesh_runtime_lights: Vec<SpriteRuntimeLight>,
pub fog_enabled: bool,
pub fog_color: [f32; 4],
pub fog_near: f32,
pub fog_far: f32,
pub fog_scroll_x: f32,
pub fog_texture_image_id: Option<ImageId>,
pub world_no: i32,
pub billboard: bool,
pub mesh_file_name: Option<String>,
pub mesh_animation: MeshAnimationState,
pub mesh_kind: u8,
pub shadow_cast: bool,
pub shadow_receive: bool,
pub wipe_fx_mode: u8,
pub wipe_fx_params: [f32; 4],
pub wipe_src_image_id: Option<ImageId>,
pub tr: u8,
pub mono: u8,
pub reverse: u8,
pub bright: u8,
pub dark: u8,
pub color_rate: u8,
pub color_add_r: u8,
pub color_add_g: u8,
pub color_add_b: u8,
pub color_r: u8,
pub color_g: u8,
pub color_b: u8,
pub mask_mode: u8,
pub blend: SpriteBlend,
pub dst_clip: Option<ClipRect>,
pub src_clip: Option<ClipRect>,
pub order: i32,
}Fields
image_id: Option<ImageId>mask_image_id: Option<ImageId>mask_offset_x: i32mask_offset_y: i32tonecurve_image_id: Option<ImageId>tonecurve_row: f32tonecurve_sat: f32fit: SpriteFitsize_mode: SpriteSizeModevisible: boolalpha: u8x: i32y: i32z: f32scale_x: f32scale_y: f32scale_z: f32rotate: f32rotate_x: f32rotate_y: f32pivot_x: f32pivot_y: f32pivot_z: f32object_anchor: boolSiglus object sprites use OBJECT.X/Y as the render anchor. For G00/PCT object resources, vertices are offset by OBJECT.CENTER plus the texture center stored in the cut metadata. Runtime helper sprites keep this off and continue to use x/y as a top-left pixel rectangle.
texture_center_x: f32texture_center_y: f32camera_enabled: boolcamera_eye: [f32; 3]camera_target: [f32; 3]camera_up: [f32; 3]camera_view_angle_deg: f32culling: boolalpha_test: boolalpha_blend: boolfog_use: boollight_no: i32light_enabled: boollight_diffuse: [f32; 4]light_ambient: [f32; 4]light_specular: [f32; 4]light_factor: f32light_kind: i32light_pos: [f32; 4]light_dir: [f32; 4]light_atten: [f32; 4]light_cone: [f32; 4]mesh_runtime_lights: Vec<SpriteRuntimeLight>fog_enabled: boolfog_color: [f32; 4]fog_near: f32fog_far: f32fog_scroll_x: f32fog_texture_image_id: Option<ImageId>world_no: i32billboard: boolmesh_file_name: Option<String>mesh_animation: MeshAnimationStatemesh_kind: u80 = regular sprite or 2D camera quad, 1 = static mesh, 2 = billboard mesh, 3 = skinned mesh.
shadow_cast: boolshadow_receive: boolwipe_fx_mode: u8Runtime wipe/effect family applied by the renderer. 0=none, 1=mosaic, 2=raster_h, 3=raster_v, 4=explosion_blur, 5=shimi, 6=shimi_inv, 10=cross_mosaic, 11=cross_raster_h, 12=cross_raster_v, 13=cross_explosion_blur.
wipe_fx_params: [f32; 4]wipe_src_image_id: Option<ImageId>Optional secondary source texture for dual-source wipe/effect composition.
tr: u8mono: u8reverse: u8bright: u8dark: u8color_rate: u8color_add_r: u8color_add_g: u8color_add_b: u8color_r: u8color_g: u8color_b: u8mask_mode: u80 = off, 1 = use luminance as alpha, 2 = use texture alpha.
blend: SpriteBlenddst_clip: Option<ClipRect>src_clip: Option<ClipRect>order: i32Render order within a layer (ascending).